==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetVirtualNetworkGatewayConnectionIkeSasPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group.
 * @property virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
 */
public data class GetVirtualNetworkGatewayConnectionIkeSasPlainArgs(
    public val resourceGroupName: String,
    public val virtualNetworkGatewayConnectionName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs =
        com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .virtualNetworkGatewayConnectionName(
                virtualNetworkGatewayConnectionName.let({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [GetVirtualNetworkGatewayConnectionIkeSasPlainArgs].
 */
@PulumiTagMarker
public class GetVirtualNetworkGatewayConnectionIkeSasPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var virtualNetworkGatewayConnectionName: String? = null

    /**
     * @param value The name of the resource group.
     */
    @JvmName("kckvejeeoetqotrc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the virtual network gateway Connection.
     */
    @JvmName("htepoigbvnfdgxat")
    public suspend fun virtualNetworkGatewayConnectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualNetworkGatewayConnectionName = mapped
    }

    internal fun build(): GetVirtualNetworkGatewayConnectionIkeSasPlainArgs =
        GetVirtualNetworkGatewayConnectionIkeSasPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            virtualNetworkGatewayConnectionName = virtualNetworkGatewayConnectionName ?: throw
                PulumiNullFieldException("virtualNetworkGatewayConnectionName"),
        )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetVirtualNetworkGatewayConnectionIkeSasPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group.
 * @property virtualNetworkGatewayConnectionName The name of the virtual network gateway Connection.
 */
public data class GetVirtualNetworkGatewayConnectionIkeSasPlainArgs(
    public val resourceGroupName: String,
    public val virtualNetworkGatewayConnectionName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs =
        com.pulumi.azurenative.network.inputs.GetVirtualNetworkGatewayConnectionIkeSasPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .virtualNetworkGatewayConnectionName(
                virtualNetworkGatewayConnectionName.let({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [GetVirtualNetworkGatewayConnectionIkeSasPlainArgs].
 */
@PulumiTagMarker
public class GetVirtualNetworkGatewayConnectionIkeSasPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var virtualNetworkGatewayConnectionName: String? = null

    /**
     * @param value The name of the resource group.
     */
    @JvmName("wjjjxdnuncdjvxuv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the virtual network gateway Connection.
     */
    @JvmName("fnrmwgjakpyclvct")
    public suspend fun virtualNetworkGatewayConnectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualNetworkGatewayConnectionName = mapped
    }

    internal fun build(): GetVirtualNetworkGatewayConnectionIkeSasPlainArgs =
        GetVirtualNetworkGatewayConnectionIkeSasPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            virtualNetworkGatewayConnectionName = virtualNetworkGatewayConnectionName ?: throw
                PulumiNullFieldException("virtualNetworkGatewayConnectionName"),
        )
}
